================================================================================
yehua - Let you focus on code, instead of setup scaffolding
================================================================================

.. image:: https://api.travis-ci.org/chfw/yehua.svg?branch=master
   :target: http://travis-ci.org/chfw/yehua

.. image:: https://codecov.io/github/chfw/yehua/coverage.png
    :target: https://codecov.io/github/chfw/yehua

.. image:: https://readthedocs.org/projects/yehua/badge/?version=latest
   :target: http://yehua.readthedocs.org/en/latest/

.. image:: https://badges.gitter.im/chfw_yehua/Lobby.svg
   :alt: Join the chat at https://gitter.im/chfw_yehua/Lobby
   :target: https://gitter.im/chfw_yehua/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


Installation
================================================================================

You can install it via pip:

.. code-block:: bash

    $ pip install yehua


or clone it and install it:

.. code-block:: bash

    $ git clone http://github.com/chfw/yehua.git
    $ cd yehua
    $ python setup.py install

Usage
================================================================================

.. image:: https://github.com/chfw/yehua/raw/master/yehua-usage.gif
   :width: 600px

Simply type in ::

    $ yehua

And then go into the generate project folder::

    $ moban
